from .__set_data__ import Paths

__root__ = getattr(Paths, "root")
__data__ = getattr(Paths, "data")
__gui__ = getattr(Paths, "gui")
__scraper__ = getattr(Paths, "scraper")
__utils__ = getattr(Paths, "utils")
__icons__ = getattr(Paths, "icons")
__buttons__ = getattr(Paths, "buttons")
