from .__set_data__ import VideoFile

__video_name__ = getattr(VideoFile, "name")
__video_ext__ = getattr(VideoFile, "ext")
__video_path__ = getattr(VideoFile, "path")
__video_directory__ = getattr(VideoFile, "directory")
