from .__set_data__ import SetValues

SetValues()
from .__paths__ import (
    __buttons__,
    __data__,
    __gui__,
    __icons__,
    __root__,
    __scraper__,
    __utils__,
)
from .__version__ import __version__
from .__video__ import (
    __video_directory__,
    __video_ext__,
    __video_name__,
    __video_path__,
)
